@@ -1,5 +1,5 @@
-use super::helpers::fixtures::get_language;
-use tree_sitter::{allocations, Parser};
+use super::helpers::{allocations, fixtures::get_language};
+use tree_sitter::Parser;
 
 #[test]
 fn test_pathological_example_1() {
